@@ -126,7 +126,7 @@ class TestJobLock(unittest.TestCase, contextlib.ExitStack):
     with JobLock(self.tmpdir/"lock1.lock", corruptfiletimeout=datetime.timedelta(seconds=.1)) as lock:
       self.assertFalse(lock)
     self.assertFalse((self.tmpdir/"lock1.lock_2").exists())
-    self.assertFalse((self.tmpdir/"lock1.lock_5").exists())
+    self.assertTrue((self.tmpdir/"lock1.lock_5").exists())
     self.assertTrue((self.tmpdir/"lock1.lock_10").exists())
     self.assertFalse((self.tmpdir/"lock1.lock_30").exists())
     time.sleep(.1)
